#ifndef YYSTYPE_HEADER
#define YYSTYPE_HEADER
union KC_YYSTYPE {
    kc::nocasestring yt_nocasestring;
    kc::casestring yt_casestring;
    kc::real yt_real;
    kc::integer yt_integer;
    kc::voidptr yt_voidptr;
    kc::tProcess yt_tProcess;
    kc::activity yt_activity;
    kc::activity_list yt_activity_list;
    kc::tPartnerLink_list yt_tPartnerLink_list;
    kc::tPartnerLink yt_tPartnerLink;
    kc::tPartner_list yt_tPartner_list;
    kc::tPartner yt_tPartner;
    kc::tFaultHandlers yt_tFaultHandlers;
    kc::tCatch_list yt_tCatch_list;
    kc::tCatch yt_tCatch;
    kc::tCatchAll yt_tCatchAll;
    kc::tTerminationHandler yt_tTerminationHandler;
    kc::tCompensationHandler yt_tCompensationHandler;
    kc::tEventHandlers yt_tEventHandlers;
    kc::tOnMessage_list yt_tOnMessage_list;
    kc::tOnMessage yt_tOnMessage;
    kc::tOnAlarm_list yt_tOnAlarm_list;
    kc::tOnAlarm yt_tOnAlarm;
    kc::tRepeatEvery yt_tRepeatEvery;
    kc::tVariable_list yt_tVariable_list;
    kc::tVariable yt_tVariable;
    kc::tMessageExchange_list yt_tMessageExchange_list;
    kc::tMessageExchange yt_tMessageExchange;
    kc::tCorrelationSet_list yt_tCorrelationSet_list;
    kc::tCorrelationSet yt_tCorrelationSet;
    kc::tCorrelation_list yt_tCorrelation_list;
    kc::tCorrelation yt_tCorrelation;
    kc::tToPart_list yt_tToPart_list;
    kc::tToPart yt_tToPart;
    kc::tFromPart_list yt_tFromPart_list;
    kc::tFromPart yt_tFromPart;
    kc::tReceive yt_tReceive;
    kc::tReply yt_tReply;
    kc::tInvoke yt_tInvoke;
    kc::tAssign yt_tAssign;
    kc::tCopy_list yt_tCopy_list;
    kc::tCopy yt_tCopy;
    kc::tFrom yt_tFrom;
    kc::tTo yt_tTo;
    kc::tValidate yt_tValidate;
    kc::tEmpty yt_tEmpty;
    kc::tOpaqueActivity yt_tOpaqueActivity;
    kc::tWait yt_tWait;
    kc::tExit yt_tExit;
    kc::tThrow yt_tThrow;
    kc::tRethrow yt_tRethrow;
    kc::tCompensate yt_tCompensate;
    kc::tSequence yt_tSequence;
    kc::tIf yt_tIf;
    kc::tElseIf_list yt_tElseIf_list;
    kc::tElseIf yt_tElseIf;
    kc::tElse yt_tElse;
    kc::tWhile yt_tWhile;
    kc::tRepeatUntil yt_tRepeatUntil;
    kc::tForEach yt_tForEach;
    kc::tPick yt_tPick;
    kc::tFlow yt_tFlow;
    kc::tLink_list yt_tLink_list;
    kc::tLink yt_tLink;
    kc::tScope yt_tScope;
    kc::standardElements yt_standardElements;
    kc::tTarget_list yt_tTarget_list;
    kc::tTarget yt_tTarget;
    kc::tSource_list yt_tSource_list;
    kc::tSource yt_tSource;
    kc::joinCondition yt_joinCondition;
    kc::expression yt_expression;
};
#define YYSTYPE KC_YYSTYPE
#endif // YYSTYPE_HEADER
